@@ -1,5 +1,6 @@
 # coding: utf-8
-
+from .applications import ApplicationsManagementClient
+from .check_type import CheckType
 from .policies import PolicyManagementClient
 from .types import ManagementClientOptions
 from ..common.graphql import GraphqlClient
@@ -9,6 +10,7 @@ from .users import UsersManagementClient
 from .roles import RolesManagementClient
 from .acl import AclManagementClient
 from .udf import UdfManagementClient
+from ..common.rest import RestClient
 
 
 class ManagementClient(object):
@@ -20,6 +22,7 @@ class ManagementClient(object):
         self.graphqlClient = GraphqlClient(
             options=self.options, endpoint=self.options.graphql_endpoint
         )
+        self.restClient = RestClient(options=self.options)
         self.tokenProvider = ManagementTokenProvider(
             options=self.options, graphqlClient=self.graphqlClient
         )
@@ -27,6 +30,7 @@ class ManagementClient(object):
         self.users = UsersManagementClient(
             options=self.options,
             graphqlClient=self.graphqlClient,
+            restClient=self.restClient,
             tokenProvider=self.tokenProvider,
         )
 
@@ -45,6 +49,7 @@ class ManagementClient(object):
         self.acl = AclManagementClient(
             options=self.options,
             graphqlClient=self.graphqlClient,
+            restClient=self.restClient,
             tokenProvider=self.tokenProvider,
         )
 
@@ -54,9 +59,21 @@ class ManagementClient(object):
             tokenProvider=self.tokenProvider,
         )
 
+        self.applications = ApplicationsManagementClient(
+            options=self.options,
+            graphqlClient=self.graphqlClient,
+            restClient=self.restClient,
+            tokenProvider=self.tokenProvider,
+            managementClient=self
+        )
+
         # 用户池详情
         self._userpool_detail = None
 
+        # Check
+
+        self.check = CheckType()
+
     def _get_userpool_detail(self):
         if self._userpool_detail:
             return self._userpool_detail
